@@ -1,16 +1,14 @@
 from easydev import browser
 
-try:
-    from unittest.mock import patch
-except:
-    from mock import patch
+from unittest.mock import patch
 
 
 def test_browse(mocker):
     def func(*args, **kwargs):
         pass
-    with patch('webbrowser.open', func):
-        with patch('webbrowser.open_new', func):
+
+    with patch("webbrowser.open", func):
+        with patch("webbrowser.open_new", func):
             browser.browse("http://pypi.python.org", verbose=True)
             browser.browse("pypi.python.org", verbose=True)
             browser.browse(".", verbose=True)
@@ -18,12 +16,11 @@ def test_browse(mocker):
 
 def test_browse_module(mocker):
     from easydev.browser import main
+
     def func(*args, **kwargs):
         pass
-    with patch('webbrowser.open', func):
+
+    with patch("webbrowser.open", func):
         main(["browse", "--help"])
-        main(["browse", "." ])
-        main(["browse", "http://www.uniprot.org" ])
-
-
-
+        main(["browse", "."])
+        main(["browse", "http://www.uniprot.org"])
