@@ -1,23 +1,24 @@
-from easydev.misc import get_home, cmd_exists, in_ipynb
-#from mock import patch
-import subprocess
 import os.path
 
+# from unittest.mock import patch
+import subprocess
+
+from easydev.misc import cmd_exists, get_home, in_ipynb
+
 
 def test_get_home():
     get_home()
 
-
-    #with patch.object(os.path, 'expanduser') as mymock:
+    # with patch.object(os.path, 'expanduser') as mymock:
     #    mymock.side_effect = ImportError
     #    get_home()
 
 
 def test_cmd_exists():
-    assert cmd_exists('dummy_dummy') == False
-    assert cmd_exists('ls') == True
+    assert cmd_exists("dummy_dummy") == False
+    assert cmd_exists("ls") == True
 
-    #with patch.object(subprocess, 'call') as mymock:
+    # with patch.object(subprocess, 'call') as mymock:
     #    mymock.side_effect = Exception
     #    cmd_exists('ls')
 
